searchData={"items":[{"type":"module","title":"LoggerHTTP","doc":"LoggerHTTP is a simple HTTP logger for Elixir applications.","ref":"LoggerHTTP.html"},{"type":"module","title":"Installation - LoggerHTTP","doc":"Add `logger_http` to your list of dependencies in `mix.exs`. If you plan on using the\ndefault adapter - which uses the `:req` library - add it to your dependencies too:\n\n    defp deps do\n      [\n        ...\n        {:logger_http, \"~> 0.1\"},\n        {:req, \"~> 0.5\"}\n      ]\n    end","ref":"LoggerHTTP.html#module-installation"},{"type":"module","title":"Usage - LoggerHTTP","doc":"To add the LoggerHTTP handler to your system, see [the documentation for handlers in\nElixir](https://hexdocs.pm/logger/Logger.html#module-erlang-otp-handlers).\n\nYou can configure the handler in the `:logger` key under your application's configuration,\npotentially alongside other `:logger` handlers:\n\n    config :my_app, :logger, [\n      {:handler, :my_http_handler, LoggerHTTP.Handler, %{\n        config: %{url: \"https://example.com/logs\"}\n      }}\n    ]\n\nIf you do this, then you'll want to add custom handlers in your application's\n`c:Application.start/2` callback if you haven't already:\n\n    def start(_type, _args) do\n      Logger.add_handlers(:my_app)\n\n      # ...\n    end\n\nAlternatively, you can skip the `:logger` configuration and add the handler directly to\nyour application's `c:Application.start/2` callback:\n\n    def start(_type, _args) do\n      :logger.add_handler(:my_http_handler, LoggerHTTP.Handler, %{\n        config: %{url: \"https://example.com/logs\"}\n      })\n\n      # ...\n    end\n\nSee `LoggerHTTP.Handler` to configure the handler.","ref":"LoggerHTTP.html#module-usage"},{"type":"module","title":"Custom error handling - LoggerHTTP","doc":"The default behaviour when an error occurs when sending the logs is to print the error\nto `:stderr`. The log queue is kept as is and an other attempt to send them is made\nlater.\n\nIf you need to customize this behaviour while keeping sending logs as the default adapter\ndoes, you can create a custom adapter and delegate the `c:LoggerHTTP.Adapter.cast_options/1`\nand `c:LoggerHTTP.Adapter.send_logs/3` callbacks to the default adapter.\n\n    defmodule MyAdapter do\n      @behaviour LoggerHTTP.Adapter\n\n      @impl LoggerHTTP.Adapter\n      defdelegate cast_options(options), to: LoggerHTTP.Adapter.Req\n\n      @impl LoggerHTTP.Adapter\n      defdelegate send_logs(url, logs, options), to: LoggerHTTP.Adapter.Req\n\n      @impl LoggerHTTP.Adapter\n      def handle_error(error, options) do\n        # Custom error handling\n      end\n    end\n\nSee `LoggerHTTP.Adapter` for more information on creating custom adapters.","ref":"LoggerHTTP.html#module-custom-error-handling"},{"type":"behaviour","title":"LoggerHTTP.Adapter","doc":"A behaviour module for implementing a custom HTTP adapter for LoggerHTTP.\n\nThe default adapter is `LoggerHTTP.Adapter.Req`.\n\nTo configure a different adapter, implement the `LoggerHTTP.Adapter` behaviour and\nset the `:adapter` option in the logger handler configuration.\n\n    config :my_app, :logger, [\n      {:handler, :my_http_handler, LoggerHTTP.Handler, %{\n        config: %{\n          url: \"https://example.com/logs\",\n          adapter: MyApp.CustomAdapter\n        }\n      }}\n    ]\n\n> #### Be careful about using Logger in the adapter {: .warning}\n>\n> Since the adapter is called from within a logger handler, it can be very troublesome\n> to use Logger in its callbacks. Doing so can lead to an infinite number of logs being\n> created, the app slowing down, and finally the logger handler crashing and being detached.\n> Try to avoid it, and be careful if you really need it.","ref":"LoggerHTTP.Adapter.html"},{"type":"callback","title":"LoggerHTTP.Adapter.cast_options/1","doc":"Validate and cast the options given to the adapter.\n\nThis callback is called directly when adding the logger. It may raise an exception if\nthe passed options are invalid, which will lead to the logger handler failing to be\nadded.","ref":"LoggerHTTP.Adapter.html#c:cast_options/1"},{"type":"callback","title":"LoggerHTTP.Adapter.handle_error/2","doc":"Handle an error that occurred when sending the logs.\n\nThe error can be anything returned by `c:send_logs/3`. When using the default adapter,\nthe error is known to be of type `t:Exception.t/0`.","ref":"LoggerHTTP.Adapter.html#c:handle_error/2"},{"type":"callback","title":"LoggerHTTP.Adapter.send_logs/3","doc":"Send the logs to the given URL.\n\nThis callback should not handle the error directly, but rather return `{:error, reason}`.\n`c:handle_error/2` will then be called with `reason` as its first parameter.","ref":"LoggerHTTP.Adapter.html#c:send_logs/3"},{"type":"type","title":"LoggerHTTP.Adapter.options/0","doc":"The options for the adapter.\n\nThe options are given in the logger handler configuration, then validated using the\n`c:cast_options/1` callback if provided. They are then passed to the other callbacks\nto configure the adapter's behaviour.","ref":"LoggerHTTP.Adapter.html#t:options/0"},{"type":"module","title":"LoggerHTTP.Adapter.Req","doc":"An HTTP adapter for LoggerHTTP that uses the `:req` library to send logs, and\noutputs errors to `:stderr` by default, or any device.","ref":"LoggerHTTP.Adapter.Req.html"},{"type":"module","title":"Usage - LoggerHTTP.Adapter.Req","doc":"This adapter needs the `:req` library to be part of your dependencies. Add it\nto your `mix.exs` file if it is not already.\n\n    defp deps do\n      [\n        ...\n        {:req, \"~> 0.5\"}\n      ]\n    end","ref":"LoggerHTTP.Adapter.Req.html#module-usage"},{"type":"module","title":"Configuration - LoggerHTTP.Adapter.Req","doc":"This adapter supports the following configuration options:\n\n* `:method` (`t:atom/0`) - The HTTP method to use to send logs. The default value is `:post`.\n\n* `:separator` (`t:term/0`) - The separator to interleave logs with. Can be any iodata value. The default value is `10`.\n\n* `:error_device` - The device to output errors to. The default value is `:stderr`.","ref":"LoggerHTTP.Adapter.Req.html#module-configuration"},{"type":"module","title":"LoggerHTTP.Handler","doc":"A configurable [`:logger` handler](https://www.erlang.org/doc/apps/kernel/logger_chapter.html#handlers)\nthat sends logged messages through HTTP.","ref":"LoggerHTTP.Handler.html"},{"type":"module","title":"Features - LoggerHTTP.Handler","doc":"This logger handler provides the features listed here.","ref":"LoggerHTTP.Handler.html#module-features"},{"type":"module","title":"Overload protection - LoggerHTTP.Handler","doc":"This handler has built-in *[overload protection](https://www.erlang.org/doc/apps/kernel/logger_chapter.html#protecting-the-handler-from-overload)*\nvia the `:sync_threshold` and `:drop_threshold` configuration options. Under normal\ncircumstances, the logs are sent asynchronously to the HTTP endpoint, returning control\nto the caller immediately. However, if the number of queued logs exceeds the configured\n`:sync_threshold`, the handler will switch to synchronous mode, blocking the logging\nprocess until the logs are sent. Moreover, if the number of queued logs exceeds the\n`:drop_threshold`, the handler will start dropping logs to prevent the system from\nbecoming unresponsive.\n\n> #### Choosing the right values {: .warning}\n>\n> Since sending the logs is batched and there is a pool of processes, it is not abnormal\n> to have a few logs queued. With the default configuration, `:batch_size` * `:pool_size`\n> means at least a hundred logs can be queued before being sent. Keep this in mind when\n> overriding the defaults, or you might end up in sync or drop mode too early!","ref":"LoggerHTTP.Handler.html#module-overload-protection"},{"type":"module","title":"Configuration - LoggerHTTP.Handler","doc":"This handler supports the following configuration options:\n\n* `:url` (`t:String.t/0`) - Required. The HTTP endpoint to send logs to.\n\n* `:adapter` - Configuration for the adapter module, used both to send logs and\n  handle errors.\n\n  The value can be one of the following:\n  - a keyword list to configure the default adapter `LoggerHTTP.Adapter.Req`,\n  - a module implementing the`LoggerHTTP.Adapter` behaviour to use a\n  custom adapter,\n  - a 2-tuple containing a module and a keyword list to use a configured\n  custom adapter.\n\n  The configuration is validated by the callback\n  `c:LoggerHTTP.Adapter.cast_options/1` of the adapter.\n\n  The default value is `{LoggerHTTP.Adapter.Req, []}`.\n\n* `:batch_size` (`t:integer/0`) - The maximum number of logs to queue before making an HTTP request.\n  If the timeout configured by `:batch_timeout` is reached before the\n  queue as reached the configured size, less logs will be sent. Setting\n  this parameter to 1 will effectively disable batching. The default value is `10`.\n\n* `:batch_timeout` (`t:integer/0`) - The maximum time to wait before sending a batch of logs, in milliseconds.\n  If the queue reaches the size configured by `batch_size` before this\n  timeout, the logs will be sent. This parameter is only used when\n  `batch_size` is greater than 1. It can also be disabled by settings the\n  value to `0`. The default value is `5000`.\n\n* `:pool_size` (`t:integer/0`) - LoggerHTTP uses a pool of GenServers to make HTTP requests. The log\n  are evenly distributed among the processes in the pool. This option\n  allows you to configure the size of the pool.\n\n  The default is the result of `max(10, System.schedulers_online())`.\n\n* `:sync_threshold` (`t:integer/0`) - The maximum of queued logs before switching to synchronous mode.\n  In synchronous mode, the logger will await for logs to be sent\n  before returning control to the caller. This option, along with\n  `drop_threshold`, effectively implements **overload protection**. The default value is `300`.\n\n* `:drop_threshold` (`t:integer/0`) - The maximum of queued logs before dropping logs. This option, along\n  with `sync_threshold`, effectively implements **overload protection**. The default value is `2000`.","ref":"LoggerHTTP.Handler.html#module-configuration"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n<!-- changelog -->","ref":"changelog.html"},{"type":"extras","title":"0.1.0 (2024-10-07) - Change Log","doc":"","ref":"changelog.html#0-1-0-2024-10-07"},{"type":"extras","title":"Features: - Change Log","doc":"* add adapter\n\n* add overload protection\n\n* add batch timeout\n\n* batch sent logs\n\n* send logs to uri","ref":"changelog.html#features"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}